@@ -1,12 +1,13 @@
 use diesel::{result::Error, *};
-use lemmy_db_queries::{limit_and_offset, ToSafe, ViewToVec};
 use lemmy_db_schema::{
+  limit_and_offset,
+  newtypes::PersonId,
   schema::{mod_ban, person, person_alias_1},
   source::{
     moderator::ModBan,
     person::{Person, PersonAlias1, PersonSafe, PersonSafeAlias1},
   },
-  PersonId,
+  traits::{ToSafe, ViewToVec},
 };
 use serde::{Deserialize, Serialize};
 
